@@ -3,11 +3,8 @@ import uuid
 import boto3
 import psycopg2
 
-from dotenv import load_dotenv
 from typing import Any, Dict, List, Tuple
 
-load_dotenv()
-
 
 class SimpleStorageService:
     """
@@ -18,14 +15,30 @@ class SimpleStorageService:
         bucket (str): range name of files and folder
         resource (Any): instance connected to aws to reference aws s3
     """
-    def __init__(self) -> None:
+    def __init__(self, bucket_internal:str=None) -> None:
         self._session = boto3.Session(
             aws_access_key_id=os.getenv("AWS_ACCESS_KEY_ID"),
             aws_secret_access_key=os.getenv("AWS_SECRET_ACCESS_KEY")
         )
-        self._bucket = os.getenv("BUCKET")
+        self._bucket = os.getenv("BUCKET") if bucket_internal is None else bucket_internal
         self._resource = self._session.resource('s3')
 
+    def exists(self, path:str) -> bool:
+        """        
+        Method that validates whether a file exists or not
+        
+        Parameters:
+            path (str): remote path of the file to be published
+
+        Returns:
+            bool: return whether a file exists or not
+        """
+        try:
+            self._resource.Object(self._bucket, path).load()
+            return True
+        except:
+            return False
+
     def push(self, object:Any, path:str, hash:bool=False, extension:str=None) -> str:
         """        
         Method to publish files to storage
@@ -44,6 +57,19 @@ class SimpleStorageService:
         self._resource.Object(self._bucket, path).put(Body=object)
         return path
 
+    def get_bytes(self, path:str) -> Any:
+        """        
+        Method to get a byte string from a file
+        
+        Parameters:
+            path (str): remote path of the file to be published
+
+        Returns:
+            any: return the bytes of the file
+        """
+        bucket = self._resource.Bucket(self._bucket)
+        return bucket.Object(path).get().get('Body').read()
+
 class PostgresRelationalDatabaseService:
     """
     Useful class to manage the specific relational database service for postgres
@@ -63,7 +89,7 @@ class PostgresRelationalDatabaseService:
         if type(columns) == dict:
             keys = list(columns.keys())
             typed_key = ['%s' for _ in range(len(keys))]
-            return ', '.join(keys), list(columns.values())[0] if len(columns.values()) == 1 else tuple(columns.values()), ', '.join(typed_key)
+            return ', '.join(keys), list(columns.values()), ', '.join(typed_key)
         else:
             return ', '.join(columns), None, ', '.join(['%s' for _ in range(len(columns))])
 
@@ -103,8 +129,8 @@ class PostgresRelationalDatabaseService:
         """
         keys, _, typed_key = self._convert_columns_to_tuple(column_name)
         with self._connection.cursor() as cursor:
-            cursor.execute(
+            cursor.executemany(
                 query=f'INSERT INTO {table_name} ({keys}) VALUES ({typed_key});', 
-                vars=values
+                vars_list=values
             )
             self._connection.commit()
